package com.playlet.system.service;

import java.util.List;
import com.playlet.system.domain.PlayletAdviceFeedback;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 短剧意见反馈Service接口
 *
 * @author ruoyi
 * @date 2024-03-22
 */
public interface IPlayletAdviceFeedbackService extends IService<PlayletAdviceFeedback>
{
    /**
     * 查询短剧意见反馈
     *
     * @param id 短剧意见反馈主键
     * @return 短剧意见反馈
     */
    public PlayletAdviceFeedback selectPlayletAdviceFeedbackById(Long id);

    /**
     * 查询短剧意见反馈列表
     *
     * @param playletAdviceFeedback 短剧意见反馈
     * @return 短剧意见反馈集合
     */
    public List<PlayletAdviceFeedback> selectPlayletAdviceFeedbackList(PlayletAdviceFeedback playletAdviceFeedback);

    /**
     * 新增短剧意见反馈
     *
     * @param playletAdviceFeedback 短剧意见反馈
     * @return 结果
     */
    public int insertPlayletAdviceFeedback(PlayletAdviceFeedback playletAdviceFeedback);

    /**
     * 修改短剧意见反馈
     *
     * @param playletAdviceFeedback 短剧意见反馈
     * @return 结果
     */
    public int updatePlayletAdviceFeedback(PlayletAdviceFeedback playletAdviceFeedback);

    /**
     * 批量删除短剧意见反馈
     *
     * @param ids 需要删除的短剧意见反馈主键集合
     * @return 结果
     */
    public int deletePlayletAdviceFeedbackByIds(String ids);

    /**
     * 删除短剧意见反馈信息
     *
     * @param id 短剧意见反馈主键
     * @return 结果
     */
    public int deletePlayletAdviceFeedbackById(Long id);
}
