package com.playlet.web.controller.system;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.playlet.common.annotation.Log;
import com.playlet.common.enums.BusinessType;
import com.playlet.system.domain.PlayletAdviceFeedback;
import com.playlet.system.service.IPlayletAdviceFeedbackService;
import com.playlet.common.core.controller.BaseController;
import com.playlet.common.core.domain.AjaxResult;
import com.playlet.common.utils.poi.ExcelUtil;
import com.playlet.common.core.page.TableDataInfo;

/**
 * 短剧意见反馈Controller
 *
 * @author ruoyi
 * @date 2024-03-22
 */
@Controller
@RequestMapping("/system/playlet/feedback")
public class PlayletAdviceFeedbackController extends BaseController
{
    private String prefix = "system/playlet/feedback";

    @Autowired
    private IPlayletAdviceFeedbackService playletAdviceFeedbackService;

    @RequiresPermissions("playlet:feedback:view")
    @GetMapping()
    public String feedback()
    {
        return prefix + "/feedback";
    }

    /**
     * 查询短剧意见反馈列表
     */
    @RequiresPermissions("playlet:feedback:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(PlayletAdviceFeedback playletAdviceFeedback)
    {
        startPage();
        List<PlayletAdviceFeedback> list = playletAdviceFeedbackService.selectPlayletAdviceFeedbackList(playletAdviceFeedback);
        return getDataTable(list);
    }

    /**
     * 导出短剧意见反馈列表
     */
    @RequiresPermissions("playlet:feedback:export")
    @Log(title = "短剧意见反馈", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(PlayletAdviceFeedback playletAdviceFeedback)
    {
        List<PlayletAdviceFeedback> list = playletAdviceFeedbackService.selectPlayletAdviceFeedbackList(playletAdviceFeedback);
        ExcelUtil<PlayletAdviceFeedback> util = new ExcelUtil<PlayletAdviceFeedback>(PlayletAdviceFeedback.class);
        return util.exportExcel(list, "短剧意见反馈数据");
    }

    /**
     * 新增短剧意见反馈
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存短剧意见反馈
     */
    @RequiresPermissions("playlet:feedback:add")
    @Log(title = "短剧意见反馈", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(PlayletAdviceFeedback playletAdviceFeedback)
    {
        return toAjax(playletAdviceFeedbackService.insertPlayletAdviceFeedback(playletAdviceFeedback));
    }

    /**
     * 修改短剧意见反馈
     */
    @RequiresPermissions("playlet:feedback:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        PlayletAdviceFeedback playletAdviceFeedback = playletAdviceFeedbackService.selectPlayletAdviceFeedbackById(id);
        mmap.put("playletAdviceFeedback", playletAdviceFeedback);
        return prefix + "/edit";
    }

    /**
     * 修改保存短剧意见反馈
     */
    @RequiresPermissions("playlet:feedback:edit")
    @Log(title = "短剧意见反馈", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(PlayletAdviceFeedback playletAdviceFeedback)
    {
        return toAjax(playletAdviceFeedbackService.updatePlayletAdviceFeedback(playletAdviceFeedback));
    }

    /**
     * 删除短剧意见反馈
     */
    @RequiresPermissions("playlet:feedback:remove")
    @Log(title = "短剧意见反馈", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(playletAdviceFeedbackService.deletePlayletAdviceFeedbackByIds(ids));
    }
}
